package com.aucma.dms.mapper;

import com.aucma.dms.domain.DmsRealtimeStatus;
import com.aucma.dms.domain.DmsRealtimeStatusHistory;

import java.util.List;

/**
 * 设备实时状态Mapper接口
 *
 * @author Yinq
 * @date 2024-09-02
 */
public interface DmsRealtimeStatusMapper {
    /**
     * 查询设备实时状态
     *
     * @param statusId 设备实时状态主键
     * @return 设备实时状态
     */
    public DmsRealtimeStatus selectDmsRealtimeStatusByStatusId(Long statusId);

    /**
     * 查询设备实时状态列表
     *
     * @param dmsRealtimeStatus 设备实时状态
     * @return 设备实时状态集合
     */
    public List<DmsRealtimeStatus> selectDmsRealtimeStatusList(DmsRealtimeStatus dmsRealtimeStatus);

    /**
     * 新增设备实时状态
     *
     * @param dmsRealtimeStatus 设备实时状态
     * @return 结果
     */
    public int insertDmsRealtimeStatus(DmsRealtimeStatus dmsRealtimeStatus);

    /**
     * 修改设备实时状态
     *
     * @param dmsRealtimeStatus 设备实时状态
     * @return 结果
     */
    public int updateDmsRealtimeStatus(DmsRealtimeStatus dmsRealtimeStatus);

    /**
     * 删除设备实时状态
     *
     * @param statusId 设备实时状态主键
     * @return 结果
     */
    public int deleteDmsRealtimeStatusByStatusId(Long statusId);

    /**
     * 批量删除设备实时状态
     *
     * @param statusIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsRealtimeStatusByStatusIds(Long[] statusIds);

    List<DmsRealtimeStatusHistory> history(DmsRealtimeStatusHistory history);

    Long historyTimeCount(DmsRealtimeStatusHistory history);
}
